@@ -376,12 +376,7 @@ sub _unpack {
         my $s    = substr( $value, $p, $size );
         length($s) == $size or _insufficient('raw');
         $p      += $size;
-        if($_utf8) {
-            utf8::decode($s);
-            if(!utf8::is_utf8($s)) { # latin-1
-                utf8::upgrade($s);
-            }
-        }
+        utf8::decode($s) if $_utf8;
         return $s;
     }
     elsif ( $typemap[$byte] & $T_ARRAY ) {
